searchData={"items":[{"type":"module","title":"Gumroad","doc":"An unofficial [Gumroad](https://gumroad.com) API client for Elixir applications.\n\n---\n\n**⚠️ Pay heed!** This package does not yet implement the complete Gumroad API.\nSee the \"Incomplete implementation\" section below for more details.\n\n---","ref":"Gumroad.html"},{"type":"module","title":"Documentation - Gumroad","doc":"Full documentation available on [HexDocs](https://hexdocs.pm/gumroad_elixir/Gumroad.html).","ref":"Gumroad.html#module-documentation"},{"type":"module","title":"Usage - Gumroad","doc":"```elixir\niex> {:ok, products} = Gumroad.get_products()\niex> products\n[%Gumroad.Product{id: \"...\", name: \"...\"}, %Gumroad.Product{id: \"...\", name: \"...\"}]\n\niex> {:ok, subscribers} = Gumroad.get_subscribers(List.first(products).id)\niex> subscribers\n[%Gumroad.Subscriber{id: \"...\", status: \"alive\"}]\n```","ref":"Gumroad.html#module-usage"},{"type":"module","title":"Installation - Gumroad","doc":"Add `gumroad_elixir` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:gumroad_elixir, \"~> 0.1.0\"}\n  ]\nend\n```\n\nThen, configure your [Gumroad access token](https://help.gumroad.com/article/280-create-application-api):\n\n```elixir\n# config.exs\nconfig :gumroad_elixir, :access_token, \"your-gumroad-access-token\"\n```","ref":"Gumroad.html#module-installation"},{"type":"module","title":"Configuration - Gumroad","doc":"Configuration properties on the `:gumroad_elixir` application are:\n\n- `:access_token` (required) - The access token used to authenticate to the Gumroad API.\n  _(For details on how to create an access token, see [Gumroad docs](https://help.gumroad.com/article/280-create-application-api))._\n\n- `:client` (defaults to `Gumroad.Client.Live`) - The client implementation to use when handling API\n  operations. Used for switching between a mock client and one that makes requests against\n  the live Gumroad API. More details on the [`Gumroad.Client` docs](https://hexdocs.pm/gumroad_elixir/Gumroad.Client.html).","ref":"Gumroad.html#module-configuration"},{"type":"module","title":"Error handling - Gumroad","doc":"Error messages sent by Gumroad's API in response to failed requests\nare propagated as-is to your application, with the `from_gumroad` property\nset to `true`:\n\n```elixir\niex> Gumroad.get_sale(\"not-a-real-sale\")\n{:error, %Gumroad.Error{from_gumroad: true, reason: \"The sale was not found.\"}}\n```\n\nErrors caused by other reasons (like network timeouts) have the `from_gumroad`\nproperty set to `false`:\n\n```elixir\n# Disconnect wi-fi, and...\niex> Gumroad.Client.get_sale(\"not-a-real-sale\")\n{:error, %Gumroad.Error{from_gumroad: false, reason: :timeout}}\n```","ref":"Gumroad.html#module-error-handling"},{"type":"module","title":"Authentication - Gumroad","doc":"An access token is included as a parameter on each request made to the Gumroad API.\n\nTo create an access token, see [Gumroad's docs](https://help.gumroad.com/article/280-create-application-api).","ref":"Gumroad.html#module-authentication"},{"type":"module","title":"Testing - Gumroad","doc":"Gumroad doesn't currently offer a native solution for local development or testing.\nTo make up for this, this package includes local dev and testing mocks which ensure that\nyou don't have to make calls to the live Gumroad API from non-prod environments.\n\nTo use mock responses, set `:gumroad_elixir` `:client` to `Gumroad.Client.Mock` (more details on\nthe [`Gumroad.Client docs`](https://hexdocs.pm/gumroad_elixir/Gumroad.Client.html)).\n\nNow when you perform an action that would create a request against the Gumroad API, you'll get a\nmocked response instead:\n\n```elixir\niex> Gumroad.get_resource_subscriptions(\"abc\")\n{:ok,\n %Gumroad.ResourceSubscription{\n   id: \"test-resource-subscription-id\",\n   post_url: \"http://example.org\",\n   resource_name: \"abc\"\n }}\n```","ref":"Gumroad.html#module-testing"},{"type":"module","title":"Incomplete implementation - Gumroad","doc":"This package does not implement the entire Gumroad API.\nI extracted it out of a project ([Mailgrip](https://mailgrip.io)) where\nI only implemented support for the endpoints I needed.\n\nAn overall framework has been created though, with the intention of making\naddition of new endpoints straightforward.\n\nIf you'd like support for a new endpoint, I'd love for you to open a PR (my preference!)\nor otherwise open an issue and I can look into adding support.\n\n#","ref":"Gumroad.html#module-incomplete-implementation"},{"type":"module","title":"What API endpoints are implemented? - Gumroad","doc":"The following table tracks all endpoints currently available on the [Gumroad API](https://app.gumroad.com/api)\nand whether they've been implemented in this package.\n\n| Gumroad API                                                                         | Implemented? |\n| ----------------------------------------------------------------------------------- | ------------ |\n| `GET /products`                                                                     | ✅           |\n| `GET /products/:product_id/subscribers`                                             | ✅           |\n| `PUT /resource_subscriptions`                                                       | ✅           |\n| `GET /resource_subscriptions`                                                       | ✅           |\n| `DELETE /resource_subscriptions/:resource_subscription_id`                          | ✅           |\n| `GET /sales/:id`                                                                    | ✅           |\n| `GET /subscribers/:id`                                                              | ✅           |\n| `GET /sales`                                                                        | ✅           |\n| `GET /products/:id`                                                                 | ✅           |\n| `DELETE /products/:id`                                                              | ❌           |\n| `PUT /products/:id/enable`                                                          | ❌           |\n| `PUT /products/:id/disable`                                                         | ❌           |\n| `POST /products/:product_id/variant_categories`                                     | ❌           |\n| `GET /products/:product_id/variant_categories/:id`                                  | ❌           |\n| `PUT /products/:product_id/variant_categories/:id`                                  | ❌           |\n| `DELETE /products/:product_id/variant_categories/:id`                               | ❌           |\n| `GET /products/:product_id/variant_categories`                                      | ❌           |\n| `POST /products/:product_id/variant_categories/:variant_category_id/variants`       | ❌           |\n| `GET /products/:product_id/variant_categories/:variant_category_id/variants/:id`    | ❌           |\n| `PUT /products/:product_id/variant_categories/:variant_category_id/variants/:id`    | ❌           |\n| `DELETE /products/:product_id/variant_categories/:variant_category_id/variants/:id` | ❌           |\n| `GET /products/:product_id/variant_categories/:variant_category_id/variants`        | ❌           |\n| `GET /products/:product_id/offer_codes`                                             | ❌           |\n| `GET /products/:product_id/offer_codes/:id`                                         | ❌           |\n| `POST /products/:product_id/offer_codes`                                            | ❌           |\n| `PUT /products/:product_id/offer_codes/:id`                                         | ❌           |\n| `DELETE /products/:product_id/offer_codes/:id`                                      | ❌           |\n| `GET /products/:product_id/custom_fields`                                           | ❌           |\n| `POST /products/:product_id/custom_fields`                                          | ❌           |\n| `PUT /products/:product_id/custom_fields/:name`                                     | ❌           |\n| `DELETE /products/:product_id/custom_fields/:name`                                  | ❌           |\n| `GET /user`                                                                         | ❌           |\n| `PUT /sales/:id/mark_as_shipped`                                                    | ❌           |\n| `PUT /sales/:id/refund`                                                             | ❌           |\n| `POST /licenses/verify`                                                             | ❌           |\n| `PUT /licenses/enable`                                                              | ❌           |\n| `PUT /licenses/disable`                                                             | ❌           |\n| `PUT /licenses/decrement_uses_count`                                                | ❌           |\n\n#","ref":"Gumroad.html#module-what-api-endpoints-are-implemented"},{"type":"module","title":"What else needs to be done? - Gumroad","doc":"Besides supporting all API endpoints, there are a few other\nareas I'd like to tackle before calling this client \"production\nready\":\n\n- Retry mechanism in case an API request fails.\n- Telemetry.\n- Consider moving off of HTTPoison dependency and onto native httpc.","ref":"Gumroad.html#module-what-else-needs-to-be-done"},{"type":"function","title":"Gumroad.client/0","doc":"The Gumroad client to use.\n\nSetting the `:gumroad_elixir` `:client` config value will determine which client\ngets returned by this function.\n\nIn production, this will be `Gumroad.Client.Live`, for testing this will\nlikely be `Gumroad.Client.Mock`.","ref":"Gumroad.html#client/0"},{"type":"function","title":"Gumroad.create_resource_subscription/1","doc":"","ref":"Gumroad.html#create_resource_subscription/1"},{"type":"function","title":"Gumroad.delete_resource_subscription/1","doc":"","ref":"Gumroad.html#delete_resource_subscription/1"},{"type":"function","title":"Gumroad.get_product/1","doc":"","ref":"Gumroad.html#get_product/1"},{"type":"function","title":"Gumroad.get_products/0","doc":"","ref":"Gumroad.html#get_products/0"},{"type":"function","title":"Gumroad.get_resource_subscriptions/1","doc":"","ref":"Gumroad.html#get_resource_subscriptions/1"},{"type":"function","title":"Gumroad.get_sale/1","doc":"","ref":"Gumroad.html#get_sale/1"},{"type":"function","title":"Gumroad.get_sales/1","doc":"","ref":"Gumroad.html#get_sales/1"},{"type":"function","title":"Gumroad.get_subscriber/1","doc":"","ref":"Gumroad.html#get_subscriber/1"},{"type":"function","title":"Gumroad.get_subscribers/1","doc":"","ref":"Gumroad.html#get_subscribers/1"},{"type":"behaviour","title":"Gumroad.Client","doc":"Defines a behaviour of a client that can be used for performing actions against\na Gumroad implementation.\n\nTwo implementations are provided:\n\n- `Gumroad.Client.Live` - Default client used in production. This one connects to\n    the Gumroad API.\n- `Gumroad.Client.Mock` - Client to be used in tests. This returns canned responses\n    _without_ making requests to the Gurmoad API.\n\nYou can configure your application to use either of these implementation by setting\nthe `:gumroad_elixir`, `:client` config property:\n\n```elixir\n# In test mode, you'd probably want to use the Mock implementation\n# config/test.exs\nconfig :gumroad_elixir, :client, Gumroad.Client.Mock\n\n# In prod, you should use the Live implementation (which is the default)\n# config/prod.exs\nconfig :gumroad_elixir, :client, Gumroad.Client.Live\n```","ref":"Gumroad.Client.html"},{"type":"callback","title":"Gumroad.Client.create_resource_subscription/1","doc":"Subscribe to a resource.\n\nValid resource names are:\n\n- `sale`\n- `refund`\n- `dispute`\n- `dispute_won`\n- `cancellation`\n- `subscription_updated`\n- `subscription_ended`\n- `subscription_restarted`","ref":"Gumroad.Client.html#c:create_resource_subscription/1"},{"type":"callback","title":"API - Gumroad.Client.create_resource_subscription/1","doc":"When using `Gumroad.Client.Live`, this will call the Gumroad API at\n`PUT /resource_subscriptions`.","ref":"Gumroad.Client.html#c:create_resource_subscription/1-api"},{"type":"callback","title":"Gumroad.Client.delete_resource_subscription/1","doc":"Unsubscribe from a resource.","ref":"Gumroad.Client.html#c:delete_resource_subscription/1"},{"type":"callback","title":"API - Gumroad.Client.delete_resource_subscription/1","doc":"When using `Gumroad.Client.Live`, this will call the Gumroad API at\n`DELETE /resource_subscriptions/:resource_subscription_id`.","ref":"Gumroad.Client.html#c:delete_resource_subscription/1-api"},{"type":"callback","title":"Gumroad.Client.get_product/1","doc":"Retrieve the details of a product.","ref":"Gumroad.Client.html#c:get_product/1"},{"type":"callback","title":"API - Gumroad.Client.get_product/1","doc":"When using `Gumroad.Client.Live`, this will call the Gumroad API at\n`GET /products/:id`.","ref":"Gumroad.Client.html#c:get_product/1-api"},{"type":"callback","title":"Gumroad.Client.get_products/0","doc":"Retrieve all of the existing products.","ref":"Gumroad.Client.html#c:get_products/0"},{"type":"callback","title":"API - Gumroad.Client.get_products/0","doc":"When using `Gumroad.Client.Live`, this will call the Gumroad API at\n`GET /products`.","ref":"Gumroad.Client.html#c:get_products/0-api"},{"type":"callback","title":"Gumroad.Client.get_resource_subscriptions/1","doc":"Retrieve all active subscriptions for the given resource name.\n\nValid resource names are:\n- `sale`\n- `refund`\n- `dispute`\n- `dispute_won`\n- `cancellation`\n- `subscription_updated`\n- `subscription_ended`\n- `subscription_restarted`","ref":"Gumroad.Client.html#c:get_resource_subscriptions/1"},{"type":"callback","title":"API - Gumroad.Client.get_resource_subscriptions/1","doc":"When using `Gumroad.Client.Live`, this will call the Gumroad API at\n`GET /resource_subscriptions`.","ref":"Gumroad.Client.html#c:get_resource_subscriptions/1-api"},{"type":"callback","title":"Gumroad.Client.get_sale/1","doc":"Retrieve a sale by its ID.","ref":"Gumroad.Client.html#c:get_sale/1"},{"type":"callback","title":"API - Gumroad.Client.get_sale/1","doc":"When using `Gumroad.Client.Live`, this will call the Gumroad API at\n`GET /sales/:id`.","ref":"Gumroad.Client.html#c:get_sale/1-api"},{"type":"callback","title":"Gumroad.Client.get_sales/1","doc":"Retrieves all of the successful sales by the authenticated user.","ref":"Gumroad.Client.html#c:get_sales/1"},{"type":"callback","title":"Parameters - Gumroad.Client.get_sales/1","doc":"* `after` (optional, date in form YYYY-MM-DD) - Only return sales after this date\n* `before` (optional, date in form YYYY-MM-DD) - Only return sales before this date\n* `product_id` (optional) - Filter sales by this product\n* `email` (optional) - Filter sales by this email\n* `order_id` (optional) - Filter sales by this Order ID\n* `page` (number) - Return this page of results","ref":"Gumroad.Client.html#c:get_sales/1-parameters"},{"type":"callback","title":"API - Gumroad.Client.get_sales/1","doc":"When using `Gumroad.Client.Live`, this will call the Gumroad API at\n`GET /sales`.","ref":"Gumroad.Client.html#c:get_sales/1-api"},{"type":"callback","title":"Gumroad.Client.get_subscriber/1","doc":"Retrieve a subscriber by their ID.","ref":"Gumroad.Client.html#c:get_subscriber/1"},{"type":"callback","title":"API - Gumroad.Client.get_subscriber/1","doc":"When using `Gumroad.Client.Live`, this will call the Gumroad API at\n`GET /subscribers/:id`.","ref":"Gumroad.Client.html#c:get_subscriber/1-api"},{"type":"callback","title":"Gumroad.Client.get_subscribers/1","doc":"Retrieve the subscribers of the given product.","ref":"Gumroad.Client.html#c:get_subscribers/1"},{"type":"callback","title":"API - Gumroad.Client.get_subscribers/1","doc":"When using `Gumroad.Client.Live`, this will call the Gumroad API at\n`GET /products/:product_id/subcribers`.","ref":"Gumroad.Client.html#c:get_subscribers/1-api"},{"type":"type","title":"Gumroad.Client.get_sales_params/0","doc":"","ref":"Gumroad.Client.html#t:get_sales_params/0"},{"type":"module","title":"Gumroad.Product","doc":"A Gumroad product.\n\nSee the [Gumroad docs](https://app.gumroad.com/api#products) for more info.","ref":"Gumroad.Product.html"},{"type":"function","title":"Gumroad.Product.new/1","doc":"","ref":"Gumroad.Product.html#new/1"},{"type":"type","title":"Gumroad.Product.t/0","doc":"","ref":"Gumroad.Product.html#t:t/0"},{"type":"type","title":"Gumroad.Product.variant/0","doc":"","ref":"Gumroad.Product.html#t:variant/0"},{"type":"type","title":"Gumroad.Product.variant_option/0","doc":"","ref":"Gumroad.Product.html#t:variant_option/0"},{"type":"module","title":"Gumroad.ResourceSubscription","doc":"A Gumroad resource subscription.\n\nSee the [Gumroad docs](https://app.gumroad.com/api#resource-subscriptions) for more info.","ref":"Gumroad.ResourceSubscription.html"},{"type":"function","title":"Gumroad.ResourceSubscription.new/1","doc":"","ref":"Gumroad.ResourceSubscription.html#new/1"},{"type":"type","title":"Gumroad.ResourceSubscription.create_params/0","doc":"","ref":"Gumroad.ResourceSubscription.html#t:create_params/0"},{"type":"type","title":"Gumroad.ResourceSubscription.t/0","doc":"","ref":"Gumroad.ResourceSubscription.html#t:t/0"},{"type":"module","title":"Gumroad.Sale","doc":"A Gumroad sale.\n\nSee the [Gumroad docs](https://app.gumroad.com/api#sales) for more info.","ref":"Gumroad.Sale.html"},{"type":"function","title":"Gumroad.Sale.new/1","doc":"","ref":"Gumroad.Sale.html#new/1"},{"type":"type","title":"Gumroad.Sale.affiliate/0","doc":"","ref":"Gumroad.Sale.html#t:affiliate/0"},{"type":"type","title":"Gumroad.Sale.t/0","doc":"","ref":"Gumroad.Sale.html#t:t/0"},{"type":"module","title":"Gumroad.Subscriber","doc":"A Gumroad subscriber.\n\nSee the [Gumroad docs](https://app.gumroad.com/api#subscribers) for more info.","ref":"Gumroad.Subscriber.html"},{"type":"function","title":"Gumroad.Subscriber.new/1","doc":"","ref":"Gumroad.Subscriber.html#new/1"},{"type":"type","title":"Gumroad.Subscriber.t/0","doc":"","ref":"Gumroad.Subscriber.html#t:t/0"},{"type":"module","title":"Gumroad.Testing","doc":"Utilities to aid in writing tests that mock Gumroad instead\nof calling its live API.\n\nSee `Gumroad.Client` for more info about the `Mock`\nclient.","ref":"Gumroad.Testing.html"},{"type":"module","title":"Gumroad.Testing.Fixtures","doc":"Provides fixtures that can be used with a mock\nGumroad API client implementation, to simulate a\nresponse from Gumroad.\n\nSee `Gumroad.Client` for more info about the `Mock`\nclient.","ref":"Gumroad.Testing.Fixtures.html"},{"type":"function","title":"Gumroad.Testing.Fixtures.product/1","doc":"","ref":"Gumroad.Testing.Fixtures.html#product/1"},{"type":"function","title":"Gumroad.Testing.Fixtures.resource_subscription/1","doc":"","ref":"Gumroad.Testing.Fixtures.html#resource_subscription/1"},{"type":"function","title":"Gumroad.Testing.Fixtures.sale/1","doc":"","ref":"Gumroad.Testing.Fixtures.html#sale/1"},{"type":"function","title":"Gumroad.Testing.Fixtures.subscriber/1","doc":"","ref":"Gumroad.Testing.Fixtures.html#subscriber/1"},{"type":"exception","title":"Gumroad.Error","doc":"An error encountered while trying to query the Gumroad API.","ref":"Gumroad.Error.html"},{"type":"function","title":"Gumroad.Error.message/1","doc":"","ref":"Gumroad.Error.html#message/1"},{"type":"type","title":"Gumroad.Error.t/0","doc":"An error encountered while trying to query the Gumroad API.\n\n* `from_gumroad` - set to `true` if Gumroad was reached but\n    returned an error while processing the request.\n    Set to `false` if Gumroad could not be reached at all.\n* `reason` - set to the error message returned from Gumroad\n    when `from_gumroad` is `true`. Otherwise is an atom\n    pointing to the underlying error, i.e. `:timeout`.","ref":"Gumroad.Error.html#t:t/0"},{"type":"extras","title":"gumroad_elixir","doc":"# gumroad_elixir\n\n[![Hex.pm](https://img.shields.io/hexpm/v/gumroad_elixir)](https://hex.pm/packages/gumroad_elixir) [![Hex Docs](https://img.shields.io/badge/hex-docs-9768d1.svg)](https://hexdocs.pm/gumroad_elixir) ![.github/workflows/ci.yml](https://github.com/alexpls/gumroad_elixir/actions/workflows/ci.yml/badge.svg)\n\n \n\nAn unofficial [Gumroad](https://gumroad.com) API client for Elixir applications.\n\n---\n\n**⚠️ Pay heed!** This package does not yet implement the complete Gumroad API.\nSee the \"Incomplete implementation\" section below for more details.\n\n---","ref":"readme.html"},{"type":"extras","title":"Documentation - gumroad_elixir","doc":"Full documentation available on [HexDocs](https://hexdocs.pm/gumroad_elixir/Gumroad.html).","ref":"readme.html#documentation"},{"type":"extras","title":"Usage - gumroad_elixir","doc":"```elixir\niex> {:ok, products} = Gumroad.get_products()\niex> products\n[%Gumroad.Product{id: \"...\", name: \"...\"}, %Gumroad.Product{id: \"...\", name: \"...\"}]\n\niex> {:ok, subscribers} = Gumroad.get_subscribers(List.first(products).id)\niex> subscribers\n[%Gumroad.Subscriber{id: \"...\", status: \"alive\"}]\n```","ref":"readme.html#usage"},{"type":"extras","title":"Installation - gumroad_elixir","doc":"Add `gumroad_elixir` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:gumroad_elixir, \"~> 0.1.0\"}\n  ]\nend\n```\n\nThen, configure your [Gumroad access token](https://help.gumroad.com/article/280-create-application-api):\n\n```elixir\n# config.exs\nconfig :gumroad_elixir, :access_token, \"your-gumroad-access-token\"\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - gumroad_elixir","doc":"Configuration properties on the `:gumroad_elixir` application are:\n\n- `:access_token` (required) - The access token used to authenticate to the Gumroad API.\n  _(For details on how to create an access token, see [Gumroad docs](https://help.gumroad.com/article/280-create-application-api))._\n\n- `:client` (defaults to `Gumroad.Client.Live`) - The client implementation to use when handling API\n  operations. Used for switching between a mock client and one that makes requests against\n  the live Gumroad API. More details on the [`Gumroad.Client` docs](https://hexdocs.pm/gumroad_elixir/Gumroad.Client.html).","ref":"readme.html#configuration"},{"type":"extras","title":"Error handling - gumroad_elixir","doc":"Error messages sent by Gumroad's API in response to failed requests\nare propagated as-is to your application, with the `from_gumroad` property\nset to `true`:\n\n```elixir\niex> Gumroad.get_sale(\"not-a-real-sale\")\n{:error, %Gumroad.Error{from_gumroad: true, reason: \"The sale was not found.\"}}\n```\n\nErrors caused by other reasons (like network timeouts) have the `from_gumroad`\nproperty set to `false`:\n\n```elixir\n# Disconnect wi-fi, and...\niex> Gumroad.Client.get_sale(\"not-a-real-sale\")\n{:error, %Gumroad.Error{from_gumroad: false, reason: :timeout}}\n```","ref":"readme.html#error-handling"},{"type":"extras","title":"Authentication - gumroad_elixir","doc":"An access token is included as a parameter on each request made to the Gumroad API.\n\nTo create an access token, see [Gumroad's docs](https://help.gumroad.com/article/280-create-application-api).","ref":"readme.html#authentication"},{"type":"extras","title":"Testing - gumroad_elixir","doc":"Gumroad doesn't currently offer a native solution for local development or testing.\nTo make up for this, this package includes local dev and testing mocks which ensure that\nyou don't have to make calls to the live Gumroad API from non-prod environments.\n\nTo use mock responses, set `:gumroad_elixir` `:client` to `Gumroad.Client.Mock` (more details on\nthe [`Gumroad.Client docs`](https://hexdocs.pm/gumroad_elixir/Gumroad.Client.html)).\n\nNow when you perform an action that would create a request against the Gumroad API, you'll get a\nmocked response instead:\n\n```elixir\niex> Gumroad.get_resource_subscriptions(\"abc\")\n{:ok,\n %Gumroad.ResourceSubscription{\n   id: \"test-resource-subscription-id\",\n   post_url: \"http://example.org\",\n   resource_name: \"abc\"\n }}\n```","ref":"readme.html#testing"},{"type":"extras","title":"Incomplete implementation - gumroad_elixir","doc":"This package does not implement the entire Gumroad API.\nI extracted it out of a project ([Mailgrip](https://mailgrip.io)) where\nI only implemented support for the endpoints I needed.\n\nAn overall framework has been created though, with the intention of making\naddition of new endpoints straightforward.\n\nIf you'd like support for a new endpoint, I'd love for you to open a PR (my preference!)\nor otherwise open an issue and I can look into adding support.\n\n#","ref":"readme.html#incomplete-implementation"},{"type":"extras","title":"What API endpoints are implemented? - gumroad_elixir","doc":"The following table tracks all endpoints currently available on the [Gumroad API](https://app.gumroad.com/api)\nand whether they've been implemented in this package.\n\n| Gumroad API                                                                         | Implemented? |\n| ----------------------------------------------------------------------------------- | ------------ |\n| `GET /products`                                                                     | ✅           |\n| `GET /products/:product_id/subscribers`                                             | ✅           |\n| `PUT /resource_subscriptions`                                                       | ✅           |\n| `GET /resource_subscriptions`                                                       | ✅           |\n| `DELETE /resource_subscriptions/:resource_subscription_id`                          | ✅           |\n| `GET /sales/:id`                                                                    | ✅           |\n| `GET /subscribers/:id`                                                              | ✅           |\n| `GET /sales`                                                                        | ✅           |\n| `GET /products/:id`                                                                 | ✅           |\n| `DELETE /products/:id`                                                              | ❌           |\n| `PUT /products/:id/enable`                                                          | ❌           |\n| `PUT /products/:id/disable`                                                         | ❌           |\n| `POST /products/:product_id/variant_categories`                                     | ❌           |\n| `GET /products/:product_id/variant_categories/:id`                                  | ❌           |\n| `PUT /products/:product_id/variant_categories/:id`                                  | ❌           |\n| `DELETE /products/:product_id/variant_categories/:id`                               | ❌           |\n| `GET /products/:product_id/variant_categories`                                      | ❌           |\n| `POST /products/:product_id/variant_categories/:variant_category_id/variants`       | ❌           |\n| `GET /products/:product_id/variant_categories/:variant_category_id/variants/:id`    | ❌           |\n| `PUT /products/:product_id/variant_categories/:variant_category_id/variants/:id`    | ❌           |\n| `DELETE /products/:product_id/variant_categories/:variant_category_id/variants/:id` | ❌           |\n| `GET /products/:product_id/variant_categories/:variant_category_id/variants`        | ❌           |\n| `GET /products/:product_id/offer_codes`                                             | ❌           |\n| `GET /products/:product_id/offer_codes/:id`                                         | ❌           |\n| `POST /products/:product_id/offer_codes`                                            | ❌           |\n| `PUT /products/:product_id/offer_codes/:id`                                         | ❌           |\n| `DELETE /products/:product_id/offer_codes/:id`                                      | ❌           |\n| `GET /products/:product_id/custom_fields`                                           | ❌           |\n| `POST /products/:product_id/custom_fields`                                          | ❌           |\n| `PUT /products/:product_id/custom_fields/:name`                                     | ❌           |\n| `DELETE /products/:product_id/custom_fields/:name`                                  | ❌           |\n| `GET /user`                                                                         | ❌           |\n| `PUT /sales/:id/mark_as_shipped`                                                    | ❌           |\n| `PUT /sales/:id/refund`                                                             | ❌           |\n| `POST /licenses/verify`                                                             | ❌           |\n| `PUT /licenses/enable`                                                              | ❌           |\n| `PUT /licenses/disable`                                                             | ❌           |\n| `PUT /licenses/decrement_uses_count`                                                | ❌           |\n\n#","ref":"readme.html#what-api-endpoints-are-implemented"},{"type":"extras","title":"What else needs to be done? - gumroad_elixir","doc":"Besides supporting all API endpoints, there are a few other\nareas I'd like to tackle before calling this client \"production\nready\":\n\n- Retry mechanism in case an API request fails.\n- Telemetry.\n- Consider moving off of HTTPoison dependency and onto native httpc.","ref":"readme.html#what-else-needs-to-be-done"}],"content_type":"text/markdown"}